"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dataToString = exports.createDownloadUrl = exports.formatItemForCsvOrTsv = void 0;
const constants_1 = require("./constants");
function formatItemForCsvOrTsv(item) {
    return `"${String(item).replace(/"/g, '""')}"`;
}
exports.formatItemForCsvOrTsv = formatItemForCsvOrTsv;
function createDownloadUrl(data, fileType, charset) {
    const blob = new Blob([data], {
        type: `${constants_1.FILE_TYPE_TO_MIME_TYPE[fileType]};charset=${charset}`,
    });
    return URL.createObjectURL(blob);
}
exports.createDownloadUrl = createDownloadUrl;
function dataToString(columnNames, rows, fileType) {
    if (fileType === "JSON") {
        return JSON.stringify({ columnNames, rows }, null, 2);
    }
    else if (fileType === "CSV" || fileType === "TSV") {
        const separator = fileType === "CSV" ? "," : "\t";
        const columnNamesString = columnNames
            .map(formatItemForCsvOrTsv)
            .join(separator);
        const rowsString = rows
            .map((row) => row.map(formatItemForCsvOrTsv).join(separator))
            .join("\n");
        return [columnNamesString, rowsString].join("\n");
    }
    throw new Error(`Unknown file type: ${fileType}`);
}
exports.dataToString = dataToString;
